Update of /cvsroot/phpwiki/phpwiki/lib/plugin
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv19228/plugin
Modified Files:
WikiBlog.php
Log Message:
Blogs => Blog
Index: WikiBlog.php
===================================================================
RCS file: /cvsroot/phpwiki/phpwiki/lib/plugin/WikiBlog.php,v
retrieving revision 1.21
retrieving revision 1.22
diff -u -2 -b -p -d -r1.21 -r1.22
--- WikiBlog.php 14 Dec 2004 21:35:15 -0000 1.21
+++ WikiBlog.php 15 Dec 2004 15:33:18 -0000 1.22
@@ -116,5 +116,5 @@ extends WikiPlugin
function run($dbi, $argstr, &$request, $basepage) {
$args = $this->getArgs($argstr, $request);
// allow empty pagenames for ADMIN_USER style blogs: "Blogs/day"
//if (!$args['pagename'])
// return $this->error(_("No pagename specified"));
@@ -153,5 +153,5 @@ extends WikiPlugin
$parent = $blog['pagename'];
if (empty($parent)) {
- $prefix = ""; // allow empty parent for default "Blogs/day"
+ $prefix = ""; // allow empty parent for default "Blog/day"
$parent = HOME_PAGE;
} else {
@@ -204,5 +204,5 @@ extends WikiPlugin
// Rootname/Blog/2003-01-11/14:03:02+00:00
// This gives us natural chronological order when sorted
- // alphabetically.
+ // alphabetically. "Rootname/" is optional.
$time = Iso8601DateTime();
@@ -215,5 +215,5 @@ extends WikiPlugin
// Check intermediate pages. If not existing they should
RedirectTo the parent page.
- // Maybe add the BlogArchives plugin instead for new interim
subpage.
+ // Maybe add the BlogArchives plugin instead for the new interim
subpage.
$redirected = $prefix . $pagename;
if (!$dbi->isWikiPage($redirected)) {
@@ -311,9 +311,9 @@ extends WikiPlugin
function _blogPrefix($type='wikiblog') {
if ($type == 'wikiblog')
- $name = _("Blogs");
+ $name = "Blog";
elseif ($type == 'comment')
- $name = _("Comments");
+ $name = "Comment";
elseif ($type == 'wikiforum')
- $name = _("Messages");
+ $name = "Message"; // FIXME: we use the first 12 chars of the
summary
return $name;
}
@@ -360,4 +360,7 @@ extends WikiPlugin
// $Log$
+// Revision 1.22 2004/12/15 15:33:18 rurban
+// Blogs => Blog
+//
// Revision 1.21 2004/12/14 21:35:15 rurban
// support new BLOG_EMPTY_DEFAULT_PREFIX
-------------------------------------------------------
SF email is sponsored by - The IT Product Guide
Read honest & candid reviews on hundreds of IT Products from real users.
Discover which products truly live up to the hype. Start reading now.
@@ -116,5 +116,5 @@ extends WikiPlugin
function run($dbi, $argstr, &$request, $basepage) {
$args = $this->getArgs($argstr, $request);
- // allow empty pagenames for ADMIN_USER style blogs: "Blogs/day"
+ // allow empty pagenames for ADMIN_USER style blogs: "Blog/day"
//if (!$args['pagename'])
// return $this->error(_("No pagename specified"));
http://productguide.itmanagersjournal.com/
|
|